#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# credentials_dialog.pyw
# 
# the user should give us some user/pass info
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2014 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

if sys.platform == 'win32' or sys.platform == 'cygwin':
    import win32api
    import win32con
    import win32gui

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_CredentialsDialog import Ui_CredentialsDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class CredentialsDialog(QtGui.QDialog):

    """A dialog for letting the user pass on a user/password combo"""

    def __init__(self, user_text = 'Please provide approbitate login information:'):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_CredentialsDialog()
        self.ui.setupUi(self)
    
        # local members
        self._about_dialog = AboutDialog()

        # connectors
        self.ui.lblText.setText(user_text)
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnCancel.clicked.connect(self.reject)
        self.ui.btnOk.clicked.connect(self.clicked_ok)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
 
        t = QtCore.QTimer(self)
        t.timeout.connect(self.force_foreground)
        t.setInterval(0)
        t.setSingleShot(True)
        t.start()
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_ok(self):
        
        """Ok button has been clicked."""
        sys.stdout.write('{ ')
        sys.stdout.write('"user": "')
        sys.stdout.write(self.ui.edtUser.text())
        sys.stdout.write('", ')
        sys.stdout.write('"password": "')
        sys.stdout.write(self.ui.edtPassword.text())
        sys.stdout.write('" ')
        sys.stdout.write('}\n')
        self.accept()


    def force_foreground(self):

        """Force ourselves into foreground"""
        if sys.platform == 'win32' or sys.platform == 'cygwin':
            w = self
            while not w.nativeParentWidget() is None:
                w = w.nativeParentWidget()
            win32gui.BringWindowToTop(int(w.effectiveWinId()))
            win32gui.SetForegroundWindow(int(w.effectiveWinId()))


    def set_user_text(user_text):

        """Set a text to explain which credentials we need."""
        self.ui.lblText.setText(user_text)


if __name__ == "__main__":
    if sys.platform == 'win32' or sys.platform == 'cygwin':
        win32gui.SystemParametersInfo(win32con.SPI_SETFOREGROUNDLOCKTIMEOUT, 0, win32con.SPIF_SENDWININICHANGE | win32con.SPIF_UPDATEINIFILE)
    a = QtGui.QApplication(sys.argv)
    d = CredentialsDialog()
    d.show()
    sys.exit(a.exec_())     

